==> Bundle-Unicode-0.01.tar.gz: Bundle-Unicode-0.01/lib/Bundle/Unicode.pm <==
package Bundle::Unicode;



our $VERSION = '0.01';



1;
__END__;


=head1 NAME

Bundle::Unicode - A bundle to install Unicode modules and their dependencies

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Unicode'

=head1 CONTENTS

Unicode::Lite

Unicode::String

Unicode::Map

enum

Unicode::EastAsianWidth

ExtUtils::MakeMaker

Module::Build

Unicode::Collate

Unicode::Collate::Standard

File::Spec

Cwd

Exporter

Test

Test::More

Inline

XSLoader

Unicode::CheckUTF8

Unicode::Char

Unicode::Unihan

Fcntl

File::Path

Lingua::Han::Utils

Unicode::IMAPUtf7

Unicode::Map8

Unicode::Map

Unicode::MapUTF8

App::Info::Lib::Iconv

Encode

Module::Install

FindBin

Jcode

MIME::Base64

Unicode::UTF8simple

Unicode::Japanese

ExtUtils::Manifest

ExtUtils::Embed

Unicode::Escape

Filter::Simple

Unicode::Transliterate

AutoLoader

Clone

Unicode::Wrap

File::Copy

Unicode::Normalize

Unicode::Regex::Set

Unicode::Transform

Unicode::Decompose

Unicode::RecursiveDowngrade

String::Multibyte

String::Multibyte::Unicode

String::Multibyte::Grapheme

Acme::MetaSyntactic

Scalar::List::Util

IO::Compress::Base

Text::Unidecode

ShiftJIS::X0213::MapUTF

ShiftJIS::CP932::MapUTF

ShiftJIS::CP932::Correct

Convert::Base32

Convert::RACE

HTML::Fraction

String::Fraction

XML::Simple

YAML

Convert::CharMap

Config

File::Spec::Functions

File::Basename

Scalar::Util

AppConfig

Template

Template::Config

version

Template::Provider::Unicode::Japanese

Bundle::Encode

ShiftJIS::Collate

ShiftJIS::Regexp

encoding::warnings

Locale::Recode

TeX::Encode

Pod::LaTeX

Pod::Find

Pod::ParseUtils

Pod::Select

Locale::Maketext

Locale::Maketext::Lexicon

Locale::Maketext::Simple

i18n

Convert::ASCIInames

Apache::GuessCharset

HTML::Entities

HTML::Parser



=head2 EXPORT

None by default.


=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut

==> Bundle-Unicode-0.02.tar.gz: Bundle-Unicode-0.02/lib/Bundle/Unicode.pm <==
package Bundle::Unicode;



our $VERSION = '0.02';



1;
__END__;


=head1 NAME

Bundle::Unicode - A bundle to install Unicode modules and their dependencies

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Unicode'

=head1 CONTENTS

Unicode::Lite

Unicode::String

Unicode::Map

enum

Unicode::EastAsianWidth

ExtUtils::MakeMaker

Module::Build

Unicode::Collate

Unicode::Collate::Standard

File::Spec

Cwd

Exporter

Test

Test::More

Inline

XSLoader

Unicode::CheckUTF8

Unicode::Char

Unicode::Unihan

Fcntl

File::Path

Lingua::Han::Utils

Unicode::IMAPUtf7

Unicode::Map8

Unicode::Map

Unicode::MapUTF8

App::Info::Lib::Iconv

Encode

Module::Install

FindBin

Jcode

MIME::Base64

Unicode::UTF8simple

Unicode::Japanese

ExtUtils::Manifest

ExtUtils::Embed

Unicode::Escape

Filter::Simple

Unicode::Transliterate

AutoLoader

Clone

Unicode::Wrap

File::Copy

Unicode::Normalize

Unicode::Regex::Set

Unicode::Transform

Unicode::Decompose

Unicode::RecursiveDowngrade

String::Multibyte

Acme::MetaSyntactic

Scalar::List::Util

IO::Compress::Base

Text::Unidecode

ShiftJIS::X0213::MapUTF

ShiftJIS::CP932::MapUTF

ShiftJIS::CP932::Correct

Convert::Base32

Convert::RACE

HTML::Fraction

String::Fraction

XML::Simple

YAML

Convert::CharMap

Config

File::Spec::Functions

File::Basename

Scalar::Util

AppConfig

Template

Template::Config

version

Template::Provider::Unicode::Japanese

Bundle::Encode

ShiftJIS::Collate

ShiftJIS::Regexp

encoding::warnings

Locale::Recode

TeX::Encode

Pod::LaTeX

Pod::Find

Pod::ParseUtils

Pod::Select

Locale::Maketext

Locale::Maketext::Lexicon

Locale::Maketext::Simple

i18n

Convert::ASCIInames

Apache::GuessCharset

HTML::Entities

HTML::Parser

Unicode::Overload

Catalyst::Plugin::Unicode

Catalyst::Plugin::Unicode::Encoding

Class::Data::Inheritable

Lingua::KO::MacKorean

Lingua::JA::MacJapanese

Lingua::ZH::MacChinese::Simplified

Lingua::ZH::MacChinese::Traditional

Lingua::FA::MacFarsi

Lingua::AR::Arabic

Lingua::HE::MacHebrew

Convert::DUDE

Audio::Taglib

Text::Metaphone

BerkeleyDB

Encode::MAB2table

Lingua::KO::Hangul::Util

Template::Provider::Encoding

Lingua::FA::Number

Unicode::Indic::Bengali

Lingua::RU::Charset

DBIx::Class

BerkeleyDB

Encode::JavaScript::UCS

File::BOM

Convert::Recode

I18N::Charset

I18N::Collate

I18N::LangTags

Net::IDN::Nameprep

Net::IDN::Encode

Sort::ArbBiLex

Local::Constants

Locale::PGetText



=head2 EXPORT

None by default.


=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut
